@@ -181,39 +181,6 @@ gdk_pixbuf_finalize (GObject *object)
         
         G_OBJECT_CLASS (gdk_pixbuf_parent_class)->finalize (object);
 }
-
-
-/**
- * gdk_pixbuf_ref:
- * @pixbuf: A pixbuf.
- *
- * Adds a reference to a pixbuf. 
- *
- * Return value: The same as the @pixbuf argument.
- *
- * Deprecated: Use g_object_ref().
- **/
-GdkPixbuf *
-gdk_pixbuf_ref (GdkPixbuf *pixbuf)
-{
-        return (GdkPixbuf *) g_object_ref (pixbuf);
-}
-
-/**
- * gdk_pixbuf_unref:
- * @pixbuf: A pixbuf.
- *
- * Removes a reference from a pixbuf. 
- *
- * Deprecated: Use g_object_unref().
- **/
-void
-gdk_pixbuf_unref (GdkPixbuf *pixbuf)
-{
-        g_object_unref (pixbuf);
-}
-
-
 
 /* Used as the destroy notification function for gdk_pixbuf_new() */
 static void
@@ -291,7 +258,7 @@ gdk_pixbuf_copy (const GdkPixbuf *pixbuf)
 	guchar *buf;
 	int size;
 
-	g_return_val_if_fail (pixbuf != NULL, NULL);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
 
 	/* Calculate a semi-exact size.  Here we copy with full rowstrides;
 	 * maybe we should copy each row individually with the minimum
@@ -385,7 +352,7 @@ gdk_pixbuf_new_subpixbuf (GdkPixbuf *src_pixbuf,
 GdkColorspace
 gdk_pixbuf_get_colorspace (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, GDK_COLORSPACE_RGB);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), GDK_COLORSPACE_RGB);
 
 	return pixbuf->colorspace;
 }
@@ -401,7 +368,7 @@ gdk_pixbuf_get_colorspace (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_n_channels (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->n_channels;
 }
@@ -417,7 +384,7 @@ gdk_pixbuf_get_n_channels (const GdkPixbuf *pixbuf)
 gboolean
 gdk_pixbuf_get_has_alpha (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, FALSE);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), FALSE);
 
 	return pixbuf->has_alpha ? TRUE : FALSE;
 }
@@ -433,7 +400,7 @@ gdk_pixbuf_get_has_alpha (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_bits_per_sample (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->bits_per_sample;
 }
@@ -451,7 +418,7 @@ gdk_pixbuf_get_bits_per_sample (const GdkPixbuf *pixbuf)
 guchar *
 gdk_pixbuf_get_pixels (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, NULL);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
 
 	return pixbuf->pixels;
 }
@@ -467,7 +434,7 @@ gdk_pixbuf_get_pixels (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_width (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->width;
 }
@@ -483,7 +450,7 @@ gdk_pixbuf_get_width (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_height (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->height;
 }
@@ -500,7 +467,7 @@ gdk_pixbuf_get_height (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_rowstride (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->rowstride;
 }
