@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
+#if !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
 #error "Only <gdk/gdk.h> can be included directly."
 #endif
 
@@ -107,11 +107,6 @@ struct _GdkDragContextClass {
 GType            gdk_drag_context_get_type   (void) G_GNUC_CONST;
 GdkDragContext * gdk_drag_context_new        (void);
 
-#ifndef GDK_DISABLE_DEPRECATED
-void             gdk_drag_context_ref        (GdkDragContext *context);
-void             gdk_drag_context_unref      (GdkDragContext *context);
-#endif
-
 /* Destination side */
 
 void             gdk_drag_status        (GdkDragContext   *context,
@@ -130,9 +125,10 @@ GdkAtom          gdk_drag_get_selection (GdkDragContext   *context);
 GdkDragContext * gdk_drag_begin      (GdkWindow      *window,
 				      GList          *targets);
 
-guint32 gdk_drag_get_protocol_for_display (GdkDisplay       *display,
-					   guint32           xid,
-					   GdkDragProtocol  *protocol);
+GdkNativeWindow gdk_drag_get_protocol_for_display (GdkDisplay       *display,
+						   GdkNativeWindow   xid,
+						   GdkDragProtocol  *protocol);
+
 void    gdk_drag_find_window_for_screen   (GdkDragContext   *context,
 					   GdkWindow        *drag_window,
 					   GdkScreen        *screen,
@@ -142,8 +138,9 @@ void    gdk_drag_find_window_for_screen   (GdkDragContext   *context,
 					   GdkDragProtocol  *protocol);
 
 #ifndef GDK_MULTIHEAD_SAFE
-guint32 gdk_drag_get_protocol (guint32           xid,
-			       GdkDragProtocol  *protocol);
+GdkNativeWindow gdk_drag_get_protocol (GdkNativeWindow   xid,
+				       GdkDragProtocol  *protocol);
+
 void    gdk_drag_find_window  (GdkDragContext   *context,
 			       GdkWindow        *drag_window,
 			       gint              x_root,
