@@ -471,6 +471,7 @@ gdk_event_copy (const GdkEvent *event)
       break;
       
     case GDK_EXPOSE:
+    case GDK_DAMAGE:
       if (event->expose.region)
 	new_event->expose.region = gdk_region_copy (event->expose.region);
       break;
@@ -510,7 +511,7 @@ gdk_event_copy (const GdkEvent *event)
  * Frees a #GdkEvent, freeing or decrementing any resources associated with it.
  * Note that this function should only be called with events returned from
  * functions such as gdk_event_peek(), gdk_event_get(),
- * gdk_event_get_graphics_expose() and gdk_event_copy().
+ * gdk_event_get_graphics_expose(), gdk_event_copy() and gdk_event_new().
  **/
 void
 gdk_event_free (GdkEvent *event)
@@ -548,6 +549,7 @@ gdk_event_free (GdkEvent *event)
       break;
       
     case GDK_EXPOSE:
+    case GDK_DAMAGE:
       if (event->expose.region)
 	gdk_region_destroy (event->expose.region);
       break;
@@ -1097,7 +1099,7 @@ gdk_io_invoke (GIOChannel   *source,
  * Returns: a tag that can later be used as an argument to
  * gdk_input_remove().
  *
- * Deprecated: Use g_io_add_watch_full() on a #GIOChannel
+ * Deprecated: 2.14: Use g_io_add_watch_full() on a #GIOChannel
  */
 gint
 gdk_input_add_full (gint	      source,
@@ -1145,7 +1147,7 @@ gdk_input_add_full (gint	      source,
  * Returns: a tag that can later be used as an argument to
  * gdk_input_remove().
  *
- * Deprecated: Use g_io_add_watch() on a #GIOChannel
+ * Deprecated: 2.14: Use g_io_add_watch() on a #GIOChannel
  */
 gint
 gdk_input_add (gint		 source,
