@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
+#if !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
 #error "Only <gdk/gdk.h> can be included directly."
 #endif
 
@@ -100,16 +100,16 @@ struct _GdkDevice
   GObject parent_instance;
   /* All fields are read-only */
 	  
-  gchar *GSEAL (name);
-  GdkInputSource GSEAL (source);
-  GdkInputMode GSEAL (mode);
-  gboolean GSEAL (has_cursor);   /* TRUE if the X pointer follows device motion */
+  gchar *name;
+  GdkInputSource source;
+  GdkInputMode mode;
+  gboolean has_cursor;	     /* TRUE if the X pointer follows device motion */
 	  
-  gint GSEAL (num_axes);
-  GdkDeviceAxis *GSEAL (axes);
+  gint num_axes;
+  GdkDeviceAxis *axes;
 	  
-  gint GSEAL (num_keys);
-  GdkDeviceKey *GSEAL (keys);
+  gint num_keys;
+  GdkDeviceKey *keys;
 };
 
 /* We don't allocate each coordinate this big, but we use it to
@@ -130,19 +130,6 @@ GType          gdk_device_get_type      (void) G_GNUC_CONST;
 GList *        gdk_devices_list              (void);
 #endif /* GDK_MULTIHEAD_SAFE */
 
-G_CONST_RETURN gchar *gdk_device_get_name       (GdkDevice *device);
-GdkInputSource        gdk_device_get_source     (GdkDevice *device);
-GdkInputMode          gdk_device_get_mode       (GdkDevice *device);
-gboolean              gdk_device_get_has_cursor (GdkDevice *device);
-
-void                  gdk_device_get_key        (GdkDevice       *device,
-                                                 guint            index,
-                                                 guint           *keyval,
-                                                 GdkModifierType *modifiers);
-GdkAxisUse            gdk_device_get_axis_use   (GdkDevice       *device,
-                                                 guint            index);
-gint                  gdk_device_get_n_axes     (GdkDevice       *device);
-
 /* Functions to configure a device */
 void           gdk_device_set_source    (GdkDevice      *device,
 					 GdkInputSource  source);
