@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -52,11 +52,11 @@ typedef struct _GtkButtonBoxClass  GtkButtonBoxClass;
 struct _GtkButtonBox
 {
   GtkBox box;
-  gint child_min_width;
-  gint child_min_height;
-  gint child_ipad_x;
-  gint child_ipad_y;
-  GtkButtonBoxStyle layout_style;
+  gint GSEAL (child_min_width);
+  gint GSEAL (child_min_height);
+  gint GSEAL (child_ipad_x);
+  gint GSEAL (child_ipad_y);
+  GtkButtonBoxStyle GSEAL (layout_style);
 };
 
 struct _GtkButtonBoxClass
@@ -76,24 +76,6 @@ void              gtk_button_box_set_child_secondary (GtkButtonBox      *widget,
 						      GtkWidget         *child,
 						      gboolean           is_secondary);
 
-#ifndef GTK_DISABLE_DEPRECATED
-#define gtk_button_box_set_spacing(b,s) gtk_box_set_spacing (GTK_BOX (b), s)
-#define gtk_button_box_get_spacing(b)   gtk_box_get_spacing (GTK_BOX (b))
-
-void gtk_button_box_set_child_size     (GtkButtonBox *widget,
-					gint          min_width,
-					gint          min_height);
-void gtk_button_box_set_child_ipadding (GtkButtonBox *widget,
-					gint          ipad_x,
-					gint          ipad_y);
-void gtk_button_box_get_child_size     (GtkButtonBox *widget,
-					gint         *min_width,
-					gint         *min_height);
-void gtk_button_box_get_child_ipadding (GtkButtonBox *widget,
-					gint         *ipad_x,
-					gint         *ipad_y);
-#endif
-
 /* Internal method - do not use. */
 void _gtk_button_box_child_requisition (GtkWidget *widget,
 					int       *nvis_children,
