@@ -37,6 +37,7 @@
 #include "gtkstock.h"
 #include "gtkiconfactory.h"
 #include "gtkactivatable.h"
+#include "gtkextendedlayout.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
 #include "gtkalias.h"
@@ -111,8 +112,6 @@ static void gtk_button_unrealize (GtkWidget * widget);
 static void gtk_button_map (GtkWidget * widget);
 static void gtk_button_unmap (GtkWidget * widget);
 static void gtk_button_style_set (GtkWidget * widget, GtkStyle * prev_style);
-static void gtk_button_size_request (GtkWidget * widget,
-				     GtkRequisition * requisition);
 static void gtk_button_size_allocate (GtkWidget * widget,
 				      GtkAllocation * allocation);
 static gint gtk_button_expose (GtkWidget * widget, GdkEventExpose * event);
@@ -148,7 +147,7 @@ static void gtk_button_grab_notify     (GtkWidget             *widget,
 					gboolean               was_grabbed);
 
 
-static void gtk_button_activatable_interface_init         (GtkActivatableIface  *iface);
+static void gtk_button_activatable_interface_init(GtkActivatableIface  *iface);
 static void gtk_button_update                    (GtkActivatable       *activatable,
 				                  GtkAction            *action,
 			                          const gchar          *property_name);
@@ -159,11 +158,21 @@ static void gtk_button_set_related_action        (GtkButton            *button,
 static void gtk_button_set_use_action_appearance (GtkButton            *button,
 						  gboolean              use_appearance);
 
+static void gtk_button_extended_layout_init      (GtkExtendedLayoutIface *iface);
+static void gtk_button_get_desired_width         (GtkExtendedLayout      *layout,
+						  gint                   *minimum_size,
+						  gint                   *natural_size);
+static void gtk_button_get_desired_height        (GtkExtendedLayout      *layout,
+						  gint                   *minimum_size,
+						  gint                   *natural_size);
+  
 static guint button_signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE_WITH_CODE (GtkButton, gtk_button, GTK_TYPE_BIN,
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_ACTIVATABLE,
-						gtk_button_activatable_interface_init))
+						gtk_button_activatable_interface_init)
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_EXTENDED_LAYOUT,
+						gtk_button_extended_layout_init))
 
 static void
 gtk_button_class_init (GtkButtonClass *klass)
@@ -191,7 +200,6 @@ gtk_button_class_init (GtkButtonClass *klass)
   widget_class->map = gtk_button_map;
   widget_class->unmap = gtk_button_unmap;
   widget_class->style_set = gtk_button_style_set;
-  widget_class->size_request = gtk_button_size_request;
   widget_class->size_allocate = gtk_button_size_allocate;
   widget_class->expose_event = gtk_button_expose;
   widget_class->button_press_event = gtk_button_button_press;
@@ -1331,49 +1339,6 @@ gtk_button_get_props (GtkButton *button,
   if (interior_focus)
     gtk_widget_style_get (widget, "interior-focus", interior_focus, NULL);
 }
-	
-static void
-gtk_button_size_request (GtkWidget      *widget,
-			 GtkRequisition *requisition)
-{
-  GtkButton *button = GTK_BUTTON (widget);
-  GtkBorder default_border;
-  GtkBorder inner_border;
-  gint focus_width;
-  gint focus_pad;
-
-  gtk_button_get_props (button, &default_border, NULL, &inner_border, NULL);
-  gtk_widget_style_get (GTK_WIDGET (widget),
-			"focus-line-width", &focus_width,
-			"focus-padding", &focus_pad,
-			NULL);
- 
-  requisition->width = ((GTK_CONTAINER (widget)->border_width +
-                         GTK_WIDGET (widget)->style->xthickness) * 2 +
-                        inner_border.left + inner_border.right);
-  requisition->height = ((GTK_CONTAINER (widget)->border_width +
-                          GTK_WIDGET (widget)->style->ythickness) * 2 +
-                         inner_border.top + inner_border.bottom);
-
-  if (gtk_widget_get_can_default (widget))
-    {
-      requisition->width += default_border.left + default_border.right;
-      requisition->height += default_border.top + default_border.bottom;
-    }
-
-  if (GTK_BIN (button)->child && gtk_widget_get_visible (GTK_BIN (button)->child))
-    {
-      GtkRequisition child_requisition;
-
-      gtk_widget_size_request (GTK_BIN (button)->child, &child_requisition);
-
-      requisition->width += child_requisition.width;
-      requisition->height += child_requisition.height;
-    }
-  
-  requisition->width += 2 * (focus_width + focus_pad);
-  requisition->height += 2 * (focus_width + focus_pad);
-}
 
 static void
 gtk_button_size_allocate (GtkWidget     *widget,
@@ -1803,6 +1768,95 @@ gtk_button_finish_activate (GtkButton *button,
     gtk_button_clicked (button);
 }
 
+
+static void
+gtk_button_extended_layout_init (GtkExtendedLayoutIface *iface)
+{
+  iface->get_desired_width  = gtk_button_get_desired_width;
+  iface->get_desired_height = gtk_button_get_desired_height;
+}
+
+static void
+gtk_button_get_desired_size (GtkExtendedLayout *layout,
+			     GtkOrientation     orientation,
+			     gint              *minimum_size,
+			     gint              *natural_size)
+{
+  GtkButton *button = GTK_BUTTON (layout);
+  GtkWidget *child;
+  GtkBorder default_border;
+  GtkBorder inner_border;
+  gint focus_width;
+  gint focus_pad;
+  gint minimum, natural;
+
+  gtk_button_get_props (button, &default_border, NULL, &inner_border, NULL);
+  gtk_widget_style_get (GTK_WIDGET (layout),
+			"focus-line-width", &focus_width,
+			"focus-padding", &focus_pad,
+			NULL);
+
+  if (orientation == GTK_ORIENTATION_HORIZONTAL)
+    {
+      minimum = ((GTK_CONTAINER (layout)->border_width +
+		  GTK_WIDGET (layout)->style->xthickness) * 2 +
+		 inner_border.left + inner_border.right);
+      
+      if (gtk_widget_get_can_default (GTK_WIDGET (layout)))
+	minimum += default_border.left + default_border.right;
+    }
+  else
+    {
+      minimum = ((GTK_CONTAINER (layout)->border_width +
+		  GTK_WIDGET (layout)->style->ythickness) * 2 +
+		 inner_border.top + inner_border.bottom);
+
+      if (gtk_widget_get_can_default (GTK_WIDGET (layout)))
+	minimum += default_border.top + default_border.bottom;
+    }  
+
+  minimum += 2 * (focus_width + focus_pad);
+  natural = minimum;
+
+  if ((child = gtk_bin_get_child (GTK_BIN (button))) && 
+      gtk_widget_get_visible (child))
+    {
+      gint child_min, child_nat;
+
+      if (orientation == GTK_ORIENTATION_HORIZONTAL)
+	gtk_extended_layout_get_desired_width (GTK_EXTENDED_LAYOUT (child), 
+					       &child_min, &child_nat);
+      else
+	gtk_extended_layout_get_desired_height (GTK_EXTENDED_LAYOUT (child), 
+						&child_min, &child_nat);
+
+      minimum += child_min;
+      natural += child_nat;
+    }
+
+  if (minimum_size)
+    *minimum_size = minimum;
+
+  if (natural_size)
+    *natural_size = natural;
+}
+
+static void 
+gtk_button_get_desired_width (GtkExtendedLayout      *layout,
+			      gint                   *minimum_size,
+			      gint                   *natural_size)
+{
+  gtk_button_get_desired_size (layout, GTK_ORIENTATION_HORIZONTAL, minimum_size, natural_size);
+}
+
+static void 
+gtk_button_get_desired_height (GtkExtendedLayout      *layout,
+			       gint                   *minimum_size,
+			       gint                   *natural_size)
+{
+  gtk_button_get_desired_size (layout, GTK_ORIENTATION_VERTICAL, minimum_size, natural_size);
+}
+
 /**
  * gtk_button_set_label:
  * @button: a #GtkButton
@@ -2250,7 +2304,7 @@ gtk_button_set_image (GtkButton *button,
  * This may have been explicitly set by gtk_button_set_image()
  * or constructed by gtk_button_new_from_stock().
  *
- * Return value: (transfer none): a #GtkWidget or %NULL in case there is no image
+ * Return value: a #GtkWidget or %NULL in case there is no image
  *
  * Since: 2.6
  */
@@ -2322,24 +2376,5 @@ gtk_button_get_image_position (GtkButton *button)
 }
 
 
-/**
- * gtk_button_get_event_window:
- * @button: a #GtkButton
- *
- * Returns the button's event window if it is realized, %NULL otherwise.
- * This function should be rarely needed.
- *
- * Return value: (transfer none): @button's event window.
- *
- * Since: 2.22
- */
-GdkWindow*
-gtk_button_get_event_window (GtkButton *button)
-{
-  g_return_val_if_fail (GTK_IS_BUTTON (button), NULL);
-
-  return button->event_window;
-}
-
 #define __GTK_BUTTON_C__
 #include "gtkaliasdef.c"  
