@@ -895,7 +895,7 @@ gtk_cell_view_set_model (GtkCellView  *cell_view,
  * Returns the model for @cell_view. If no model is used %NULL is
  * returned.
  *
- * Returns: (transfer none): a #GtkTreeModel used or %NULL
+ * Returns: a #GtkTreeModel used or %NULL
  *
  * Since: 2.16
  **/
@@ -1064,26 +1064,6 @@ gtk_cell_view_cell_layout_get_cells (GtkCellLayout *layout)
   return g_list_reverse (retval);
 }
 
-/**
- * gtk_cell_view_get_cell_renderers:
- * @cell_view: a #GtkCellView
- *
- * Returns the cell renderers which have been added to @cell_view.
- *
- * Return value: a list of cell renderers. The list, but not the
- *   renderers has been newly allocated and should be freed with
- *   g_list_free() when no longer needed.
- *
- * Since: 2.6
- *
- * Deprecated: 2.18: use gtk_cell_layout_get_cells() instead.
- **/
-GList *
-gtk_cell_view_get_cell_renderers (GtkCellView *cell_view)
-{
-  return gtk_cell_view_cell_layout_get_cells (GTK_CELL_LAYOUT (cell_view));
-}
-
 static gboolean
 gtk_cell_view_buildable_custom_tag_start (GtkBuildable  *buildable,
 					  GtkBuilder    *builder,
