@@ -21,22 +21,34 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_DEBUG_H__
 #define __GTK_DEBUG_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+#include <glib.h>
+
+G_BEGIN_DECLS
 
 typedef enum {
-  GTK_DEBUG_MISC       = 1 << 0,
-  GTK_DEBUG_PLUGSOCKET = 1 << 1,
-  GTK_DEBUG_TEXT       = 1 << 2,
-  GTK_DEBUG_TREE       = 1 << 3,
-  GTK_DEBUG_UPDATES    = 1 << 4
+  GTK_DEBUG_MISC            = 1 << 0,
+  GTK_DEBUG_PLUGSOCKET      = 1 << 1,
+  GTK_DEBUG_TEXT            = 1 << 2,
+  GTK_DEBUG_TREE            = 1 << 3,
+  GTK_DEBUG_UPDATES         = 1 << 4,
+  GTK_DEBUG_KEYBINDINGS     = 1 << 5,
+  GTK_DEBUG_MULTIHEAD       = 1 << 6,
+  GTK_DEBUG_MODULES         = 1 << 7,
+  GTK_DEBUG_GEOMETRY        = 1 << 8,
+  GTK_DEBUG_ICONTHEME       = 1 << 9,
+  GTK_DEBUG_PRINTING        = 1 << 10,
+  GTK_DEBUG_BUILDER         = 1 << 11,
+  GTK_DEBUG_EXTENDED_LAYOUT = 1 << 12,
 } GtkDebugFlag;
 
 #ifdef G_ENABLE_DEBUG
@@ -48,7 +60,7 @@ typedef enum {
 #else /* !G_ENABLE_DEBUG */
 
 #define GTK_NOTE(type, action)
-      
+
 #endif /* G_ENABLE_DEBUG */
 
 #ifdef G_OS_WIN32
@@ -63,9 +75,6 @@ typedef enum {
 
 GTKVAR guint gtk_debug_flags;
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif /* __GTK_DEBUG_H__ */
