@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -94,16 +94,6 @@ typedef enum
   GTK_BUTTONBOX_CENTER
 } GtkButtonBoxStyle;
 
-#ifndef GTK_DISABLE_DEPRECATED
-/* Curve types */
-typedef enum
-{
-  GTK_CURVE_TYPE_LINEAR,       /* linear interpolation */
-  GTK_CURVE_TYPE_SPLINE,       /* spline interpolation */
-  GTK_CURVE_TYPE_FREE          /* free form curve */
-} GtkCurveType;
-#endif
-
 typedef enum
 {
   GTK_DELETE_CHARS,
@@ -158,17 +148,6 @@ typedef enum
   GTK_SENSITIVITY_OFF
 } GtkSensitivityType;
 
-#ifndef GTK_DISABLE_DEPRECATED
-/* side types */
-typedef enum
-{
-  GTK_SIDE_TOP,
-  GTK_SIDE_BOTTOM,
-  GTK_SIDE_LEFT,
-  GTK_SIDE_RIGHT
-} GtkSideType;
-#endif /* GTK_DISABLE_DEPRECATED */
-
 /* Reading directions for text */
 typedef enum
 {
@@ -186,19 +165,6 @@ typedef enum
   GTK_JUSTIFY_FILL
 } GtkJustification;
 
-#ifndef GTK_DISABLE_DEPRECATED
-/* GtkPatternSpec match types */
-typedef enum
-{
-  GTK_MATCH_ALL,       /* "*A?A*" */
-  GTK_MATCH_ALL_TAIL,  /* "*A?AA" */
-  GTK_MATCH_HEAD,      /* "AAAA*" */
-  GTK_MATCH_TAIL,      /* "*AAAA" */
-  GTK_MATCH_EXACT,     /* "AAAAA" */
-  GTK_MATCH_LAST
-} GtkMatchType;
-#endif /* GTK_DISABLE_DEPRECATED */
-
 /* Menu keyboard movement types */
 typedef enum
 {
@@ -317,14 +283,6 @@ typedef enum
   GTK_POS_BOTTOM
 } GtkPositionType;
 
-#ifndef GTK_DISABLE_DEPRECATED
-typedef enum
-{
-  GTK_PREVIEW_COLOR,
-  GTK_PREVIEW_GRAYSCALE
-} GtkPreviewType;
-#endif /* GTK_DISABLE_DEPRECATED */
-
 /* Style for buttons */
 typedef enum
 {
@@ -341,19 +299,6 @@ typedef enum
   GTK_RESIZE_IMMEDIATE		/* Perform the resizes now */
 } GtkResizeMode;
 
-#ifndef GTK_DISABLE_DEPRECATED
-/* signal run types */
-typedef enum			/*< flags >*/
-{
-  GTK_RUN_FIRST      = G_SIGNAL_RUN_FIRST,
-  GTK_RUN_LAST       = G_SIGNAL_RUN_LAST,
-  GTK_RUN_BOTH       = (GTK_RUN_FIRST | GTK_RUN_LAST),
-  GTK_RUN_NO_RECURSE = G_SIGNAL_NO_RECURSE,
-  GTK_RUN_ACTION     = G_SIGNAL_ACTION,
-  GTK_RUN_NO_HOOKS   = G_SIGNAL_NO_HOOKS
-} GtkSignalRunType;
-#endif /* GTK_DISABLE_DEPRECATED */
-
 /* scrolling types */
 typedef enum
 {
