@@ -72,6 +72,7 @@
  *       </listitem>
  *    </varlistentry>
  * </variablelist>
+ *
  * <refsect2 id="gtkfilechooser-encodings">
  * <title>File Names and Encodings</title>
  * When the user is finished selecting files in a
@@ -254,7 +255,7 @@
  * You can change these defaults to something else.  For
  * example, to add a <keycap>Shift</keycap> modifier to a few
  * of the default bindings, you can include the following
- * fragment in your <filename>.gtkrc-2.0</filename> file:
+ * fragment in your <filename>.gtkrc-3.0</filename> file:
  * </para>
  * <programlisting>
  * binding "my-own-gtkfilechooser-bindings" {
@@ -322,14 +323,14 @@
  * 	</variablelist>
  * <note>
  *    You can create your own bindings for the
- *    GtkFileChooserDefault::location-popup signal with custom
+ *    #GtkFileChooserDefault::location-popup signal with custom
  *    <parameter>path</parameter> strings, and have a crude form
  *    of easily-to-type bookmarks.  For example, say you access
  *    the path <filename>/home/username/misc</filename> very
  *    frequently.  You could then create an <keycombo>
  *    <keycap>Alt</keycap> <keycap>M</keycap> </keycombo>
  *    shortcut by including the following in your
- *    <filename>.gtkrc-2.0</filename>:
+ *    <filename>.gtkrc-3.0</filename>:
  *    <programlisting>
  *    binding "misc-shortcut" {
  *       bind "&lt;Alt&gt;M" {
@@ -503,7 +504,11 @@
  * 	    </listitem>
  * 	  </varlistentry>
  * 	  <varlistentry>
+<<<<<<< HEAD
  * 	    <term><parameter>bookmark_indes</parameter>&nbsp;:</term>
+=======
+ * 	    <term><parameter>bookmark_index</parameter>&nbsp;:</term>
+>>>>>>> native-layout-incubator
  * 	    <listitem>
  * 	      <simpara>
  * 		index of the bookmark to switch to; the indices start at 0.
@@ -760,12 +765,6 @@ gtk_file_chooser_class_init (gpointer g_iface)
 							  GTK_TYPE_FILE_CHOOSER_ACTION,
 							  GTK_FILE_CHOOSER_ACTION_OPEN,
 							  GTK_PARAM_READWRITE));
-  g_object_interface_install_property (g_iface,
-				       g_param_spec_string ("file-system-backend",
-							    P_("File System Backend"),
-							    P_("Name of file system backend to use"),
-							    NULL, 
-							    GTK_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
   g_object_interface_install_property (g_iface,
 				       g_param_spec_object ("filter",
 							    P_("Filter"),
@@ -1626,7 +1625,7 @@ gtk_file_chooser_get_current_folder_uri (GtkFileChooser *chooser)
  * gtk_file_chooser_set_current_folder_file:
  * @chooser: a #GtkFileChooser
  * @file: the #GFile for the new folder
- * @error: location to store error, or %NULL.
+ * @error: (allow-none): location to store error, or %NULL.
  * 
  * Sets the current folder for @chooser from a #GFile.
  * Internal function, see gtk_file_chooser_set_current_folder_uri().
@@ -1671,7 +1670,7 @@ gtk_file_chooser_get_current_folder_file (GtkFileChooser *chooser)
  * gtk_file_chooser_select_file:
  * @chooser: a #GtkFileChooser
  * @file: the file to select
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Selects the file referred to by @file. An internal function. See
  * _gtk_file_chooser_select_uri().
@@ -1738,7 +1737,7 @@ gtk_file_chooser_get_files (GtkFileChooser *chooser)
  * gtk_file_chooser_set_file:
  * @chooser: a #GtkFileChooser
  * @file: the #GFile to set as current
- * @error: location to store the error, or %NULL to ignore errors.
+ * @error: (allow-none): location to store the error, or %NULL to ignore errors.
  *
  * Sets @file as the current filename for the file chooser, by changing
  * to the file's parent folder and actually selecting the file in list.  If
@@ -2027,7 +2026,7 @@ gtk_file_chooser_get_preview_file (GtkFileChooser *chooser)
  * _gtk_file_chooser_add_shortcut_folder:
  * @chooser: a #GtkFileChooser
  * @file: file for the folder to add
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Adds a folder to be displayed with the shortcut folders in a file chooser.
  * Internal function, see gtk_file_chooser_add_shortcut_folder().
@@ -2052,7 +2051,7 @@ _gtk_file_chooser_add_shortcut_folder (GtkFileChooser  *chooser,
  * _gtk_file_chooser_remove_shortcut_folder:
  * @chooser: a #GtkFileChooser
  * @file: file for the folder to remove
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Removes a folder from the shortcut folders in a file chooser.  Internal
  * function, see gtk_file_chooser_remove_shortcut_folder().
@@ -2301,7 +2300,7 @@ gtk_file_chooser_get_filter (GtkFileChooser *chooser)
  * gtk_file_chooser_add_shortcut_folder:
  * @chooser: a #GtkFileChooser
  * @folder: filename of the folder to add
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Adds a folder to be displayed with the shortcut folders in a file chooser.
  * Note that shortcut folders do not get saved, as they are provided by the
@@ -2335,7 +2334,7 @@ gtk_file_chooser_add_shortcut_folder (GtkFileChooser    *chooser,
  * gtk_file_chooser_remove_shortcut_folder:
  * @chooser: a #GtkFileChooser
  * @folder: filename of the folder to remove
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Removes a folder from a file chooser's list of shortcut folders.
  * 
@@ -2398,7 +2397,7 @@ gtk_file_chooser_list_shortcut_folders (GtkFileChooser *chooser)
  * gtk_file_chooser_add_shortcut_folder_uri:
  * @chooser: a #GtkFileChooser
  * @uri: URI of the folder to add
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Adds a folder URI to be displayed with the shortcut folders in a file
  * chooser.  Note that shortcut folders do not get saved, as they are provided
@@ -2432,7 +2431,7 @@ gtk_file_chooser_add_shortcut_folder_uri (GtkFileChooser    *chooser,
  * gtk_file_chooser_remove_shortcut_folder_uri:
  * @chooser: a #GtkFileChooser
  * @uri: URI of the folder to remove
- * @error: location to store error, or %NULL
+ * @error: (allow-none): location to store error, or %NULL
  * 
  * Removes a folder URI from a file chooser's list of shortcut folders.
  * 
