@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -32,7 +32,6 @@
 #define __GTK_MENU_SHELL_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkcontainer.h>
 
 
@@ -52,20 +51,21 @@ typedef struct _GtkMenuShellClass  GtkMenuShellClass;
 struct _GtkMenuShell
 {
   GtkContainer container;
-  
-  GList *children;
-  GtkWidget *active_menu_item;
-  GtkWidget *parent_menu_shell;
-  
-  guint button;
-  guint32 activate_time;
 
-  guint active : 1;
-  guint have_grab : 1;
-  guint have_xgrab : 1;
-  guint ignore_leave : 1;	/* unused */
-  guint menu_flag : 1;		/* unused */
-  guint ignore_enter : 1;
+  GList *GSEAL (children);
+  GtkWidget *GSEAL (active_menu_item);
+  GtkWidget *GSEAL (parent_menu_shell);
+
+  guint GSEAL (button);
+  guint32 GSEAL (activate_time);
+
+  guint GSEAL (active) : 1;
+  guint GSEAL (have_grab) : 1;
+  guint GSEAL (have_xgrab) : 1;
+  guint GSEAL (ignore_leave) : 1; /* unused */
+  guint GSEAL (menu_flag) : 1;    /* unused */
+  guint GSEAL (ignore_enter) : 1;
+  guint GSEAL (keyboard_mode) : 1;
 };
 
 struct _GtkMenuShellClass
@@ -131,6 +131,11 @@ gboolean gtk_menu_shell_get_take_focus (GtkMenuShell *menu_shell);
 void     gtk_menu_shell_set_take_focus (GtkMenuShell *menu_shell,
                                         gboolean      take_focus);
 
+void     _gtk_menu_shell_update_mnemonics  (GtkMenuShell *menu_shell);
+void     _gtk_menu_shell_set_keyboard_mode (GtkMenuShell *menu_shell,
+                                            gboolean      keyboard_mode);
+gboolean _gtk_menu_shell_get_keyboard_mode (GtkMenuShell *menu_shell);
+
 G_END_DECLS
 
 #endif /* __GTK_MENU_SHELL_H__ */
