@@ -21,29 +21,28 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_SEPARATOR_H__
 #define __GTK_SEPARATOR_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkwidget.h>
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 #define GTK_TYPE_SEPARATOR                  (gtk_separator_get_type ())
-#define GTK_SEPARATOR(obj)                  (GTK_CHECK_CAST ((obj), GTK_TYPE_SEPARATOR, GtkSeparator))
-#define GTK_SEPARATOR_CLASS(klass)          (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_SEPARATOR, GtkSeparatorClass))
-#define GTK_IS_SEPARATOR(obj)               (GTK_CHECK_TYPE ((obj), GTK_TYPE_SEPARATOR))
-#define GTK_IS_SEPARATOR_CLASS(klass)       (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SEPARATOR))
-#define GTK_SEPARATOR_GET_CLASS(obj)        (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_SEPARATOR, GtkSeparatorClass))
-
+#define GTK_SEPARATOR(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SEPARATOR, GtkSeparator))
+#define GTK_SEPARATOR_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_SEPARATOR, GtkSeparatorClass))
+#define GTK_IS_SEPARATOR(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_SEPARATOR))
+#define GTK_IS_SEPARATOR_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SEPARATOR))
+#define GTK_SEPARATOR_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_SEPARATOR, GtkSeparatorClass))
 
 
 typedef struct _GtkSeparator       GtkSeparator;
@@ -60,11 +59,8 @@ struct _GtkSeparatorClass
 };
 
 
-GtkType  gtk_separator_get_type (void) G_GNUC_CONST;
+GType       gtk_separator_get_type (void) G_GNUC_CONST;
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __GTK_SEPARATOR_H__ */
