@@ -20,6 +20,10 @@
  */
 
 #include "config.h"
+
+#include <math.h>
+#include <string.h>
+
 #include "gtktooltip.h"
 #include "gtkintl.h"
 #include "gtkwindow.h"
@@ -31,8 +35,6 @@
 
 #include "gtkalias.h"
 
-#include <string.h>
-
 #undef DEBUG_TOOLTIP
 
 
@@ -79,7 +81,7 @@ struct _GtkTooltipClass
   GObjectClass parent_class;
 };
 
-#define GTK_TOOLTIP_VISIBLE(tooltip) ((tooltip)->current_window && GTK_WIDGET_VISIBLE ((tooltip)->current_window))
+#define GTK_TOOLTIP_VISIBLE(tooltip) ((tooltip)->current_window && gtk_widget_get_visible (GTK_WIDGET((tooltip)->current_window)))
 
 
 static void       gtk_tooltip_class_init           (GtkTooltipClass *klass);
@@ -205,7 +207,7 @@ gtk_tooltip_dispose (GObject *object)
 /**
  * gtk_tooltip_set_markup:
  * @tooltip: a #GtkTooltip
- * @markup: a markup string (see <link linkend="PangoMarkupFormat">Pango markup format</link>) or %NULL
+ * @markup: (allow-none): a markup string (see <link linkend="PangoMarkupFormat">Pango markup format</link>) or %NULL
  *
  * Sets the text of the tooltip to be @markup, which is marked up
  * with the <link
@@ -231,7 +233,7 @@ gtk_tooltip_set_markup (GtkTooltip  *tooltip,
 /**
  * gtk_tooltip_set_text:
  * @tooltip: a #GtkTooltip
- * @text: a text string or %NULL
+ * @text: (allow-none): a text string or %NULL
  *
  * Sets the text of the tooltip to be @text. If @text is %NULL, the label
  * will be hidden. See also gtk_tooltip_set_markup().
@@ -255,7 +257,7 @@ gtk_tooltip_set_text (GtkTooltip  *tooltip,
 /**
  * gtk_tooltip_set_icon:
  * @tooltip: a #GtkTooltip
- * @pixbuf: a #GdkPixbuf, or %NULL
+ * @pixbuf: (allow-none): a #GdkPixbuf, or %NULL
  *
  * Sets the icon of the tooltip (which is in front of the text) to be
  * @pixbuf.  If @pixbuf is %NULL, the image will be hidden.
@@ -281,7 +283,7 @@ gtk_tooltip_set_icon (GtkTooltip *tooltip,
 /**
  * gtk_tooltip_set_icon_from_stock:
  * @tooltip: a #GtkTooltip
- * @stock_id: a stock id, or %NULL
+ * @stock_id: (allow-none): a stock id, or %NULL
  * @size: (type int): a stock icon size
  *
  * Sets the icon of the tooltip (which is in front of the text) to be
@@ -308,7 +310,7 @@ gtk_tooltip_set_icon_from_stock (GtkTooltip  *tooltip,
 /**
  * gtk_tooltip_set_icon_from_icon_name:
  * @tooltip: a #GtkTooltip
- * @icon_name: an icon name, or %NULL
+ * @icon_name: (allow-none): an icon name, or %NULL
  * @size: (type int): a stock icon size
  *
  * Sets the icon of the tooltip (which is in front of the text) to be
@@ -335,7 +337,7 @@ gtk_tooltip_set_icon_from_icon_name (GtkTooltip  *tooltip,
 /**
  * gtk_tooltip_set_icon_from_gicon:
  * @tooltip: a #GtkTooltip
- * @gicon: a #GIcon representing the icon, or %NULL
+ * @gicon: (allow-none): a #GIcon representing the icon, or %NULL
  * @size: (type int): a stock icon size
  *
  * Sets the icon of the tooltip (which is in front of the text)
@@ -362,7 +364,7 @@ gtk_tooltip_set_icon_from_gicon (GtkTooltip  *tooltip,
 /**
  * gtk_tooltip_set_custom:
  * @tooltip: a #GtkTooltip
- * @custom_widget: a #GtkWidget, or %NULL to unset the old custom widget.
+ * @custom_widget: (allow-none): a #GtkWidget, or %NULL to unset the old custom widget.
  *
  * Replaces the widget packed into the tooltip with
  * @custom_widget. @custom_widget does not get destroyed when the tooltip goes
@@ -472,9 +474,9 @@ gtk_tooltip_trigger_tooltip_query (GdkDisplay *display)
   event.motion.y = y;
   event.motion.is_hint = FALSE;
 
-  gdk_window_get_origin (window, &x, &y);
-  event.motion.x_root = event.motion.x + x;
-  event.motion.y_root = event.motion.y + y;
+  gdk_window_get_root_coords (window, x, y, &x, &y);
+  event.motion.x_root = x;
+  event.motion.y_root = y;
 
   _gtk_tooltip_handle_event (&event);
 }
@@ -553,7 +555,7 @@ child_location_foreach (GtkWidget *child,
   struct ChildLocation *child_loc = data;
 
   /* Ignore invisible widgets */
-  if (!GTK_WIDGET_DRAWABLE (child))
+  if (!gtk_widget_is_drawable (child))
     return;
 
   x = 0;
@@ -619,7 +621,7 @@ window_to_alloc (GtkWidget *dest_widget,
 		 gint      *dest_y)
 {
   /* Translate from window relative to allocation relative */
-  if (!GTK_WIDGET_NO_WINDOW (dest_widget) && dest_widget->parent)
+  if (gtk_widget_get_has_window (dest_widget) && dest_widget->parent)
     {
       gint wx, wy;
       gdk_window_get_position (dest_widget->window, &wx, &wy);
@@ -674,13 +676,15 @@ find_widget_under_pointer (GdkWindow *window,
    */
   while (window && window != event_widget->window)
     {
-      gint px, py;
+      gdouble px, py;
 
-      gdk_window_get_position (window, &px, &py);
-      child_loc.x += px;
-      child_loc.y += py;
+      gdk_window_coords_to_parent (window,
+                                   child_loc.x, child_loc.y,
+                                   &px, &py);
+      child_loc.x = px;
+      child_loc.y = py;
 
-      window = gdk_window_get_parent (window);
+      window = gdk_window_get_effective_parent (window);
     }
 
   /* Failing to find widget->window can happen for e.g. a detached handle box;
@@ -859,6 +863,39 @@ gtk_tooltip_run_requery (GtkWidget  **widget,
   return return_value;
 }
 
+static void
+get_bounding_box (GtkWidget    *widget,
+                  GdkRectangle *bounds)
+{
+  GdkWindow *window;
+  gint x, y;
+  gint w, h;
+  gint x1, y1;
+  gint x2, y2;
+  gint x3, y3;
+  gint x4, y4;
+
+  window = gtk_widget_get_parent_window (widget);
+
+  x = widget->allocation.x;
+  y = widget->allocation.y;
+  w = widget->allocation.width;
+  h = widget->allocation.height;
+
+  gdk_window_get_root_coords (window, x, y, &x1, &y1);
+  gdk_window_get_root_coords (window, x + w, y, &x2, &y2);
+  gdk_window_get_root_coords (window, x, y + h, &x3, &y3);
+  gdk_window_get_root_coords (window, x + w, y + h, &x4, &y4);
+
+#define MIN4(a,b,c,d) MIN(MIN(a,b),MIN(c,d))
+#define MAX4(a,b,c,d) MAX(MAX(a,b),MAX(c,d))
+
+  bounds->x = floor (MIN4 (x1, x2, x3, x4));
+  bounds->y = floor (MIN4 (y1, y2, y3, y4));
+  bounds->width = ceil (MAX4 (x1, x2, x3, x4)) - bounds->x;
+  bounds->height = ceil (MAX4 (y1, y2, y3, y4)) - bounds->y;
+}
+
 static void
 gtk_tooltip_position (GtkTooltip *tooltip,
 		      GdkDisplay *display,
@@ -866,56 +903,128 @@ gtk_tooltip_position (GtkTooltip *tooltip,
 {
   gint x, y;
   GdkScreen *screen;
+  gint monitor_num;
+  GdkRectangle monitor;
+  GtkRequisition requisition;
+  guint cursor_size;
+  GdkRectangle bounds;
+
+#define MAX_DISTANCE 32
 
   tooltip->tooltip_widget = new_tooltip_widget;
 
+  screen = gtk_widget_get_screen (new_tooltip_widget);
+
+  gtk_widget_size_request (GTK_WIDGET (tooltip->current_window), &requisition);
+
+  monitor_num = gdk_screen_get_monitor_at_point (screen,
+                                                 tooltip->last_x,
+                                                 tooltip->last_y);
+  gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+
+  get_bounding_box (new_tooltip_widget, &bounds);
+
   /* Position the tooltip */
-  /* FIXME: should we swap this when RTL is enabled? */
+
+  cursor_size = gdk_display_get_default_cursor_size (display);
+
+  /* Try below */
+  x = bounds.x + bounds.width / 2 - requisition.width / 2;
+  y = bounds.y + bounds.height + 4;
+
+  if (y + requisition.height <= monitor.y + monitor.height)
+    {
+      if (tooltip->keyboard_mode_enabled)
+        goto found;
+
+      if (y <= tooltip->last_y + cursor_size + MAX_DISTANCE)
+        {
+          if (tooltip->last_x + cursor_size + MAX_DISTANCE < x)
+            x = tooltip->last_x + cursor_size + MAX_DISTANCE;
+          else if (x + requisition.width < tooltip->last_x - MAX_DISTANCE)
+            x = tooltip->last_x - MAX_DISTANCE - requisition.width;
+
+          goto found;
+        }
+   }
+
+  /* Try above */
+  x = bounds.x + bounds.width / 2 - requisition.width / 2;
+  y = bounds.y - requisition.height - 4;
+
+  if (y >= monitor.y)
+    {
+      if (tooltip->keyboard_mode_enabled)
+        goto found;
+
+      if (y + requisition.height >= tooltip->last_y - MAX_DISTANCE)
+        {
+          if (tooltip->last_x + cursor_size + MAX_DISTANCE < x)
+            x = tooltip->last_x + cursor_size + MAX_DISTANCE;
+          else if (x + requisition.width < tooltip->last_x - MAX_DISTANCE)
+            x = tooltip->last_x - MAX_DISTANCE - requisition.width;
+
+          goto found;
+        }
+    }
+
+  /* Try right FIXME: flip on rtl ? */
+  x = bounds.x + bounds.width + 4;
+  y = bounds.y + bounds.height / 2 - requisition.height / 2;
+
+  if (x + requisition.width <= monitor.x + monitor.width)
+    {
+      if (tooltip->keyboard_mode_enabled)
+        goto found;
+
+      if (x <= tooltip->last_x + cursor_size + MAX_DISTANCE)
+        {
+          if (tooltip->last_y + cursor_size + MAX_DISTANCE < y)
+            y = tooltip->last_y + cursor_size + MAX_DISTANCE;
+          else if (y + requisition.height < tooltip->last_y - MAX_DISTANCE)
+            y = tooltip->last_y - MAX_DISTANCE - requisition.height;
+
+          goto found;
+        }
+    }
+
+  /* Try left FIXME: flip on rtl ? */
+  x = bounds.x - requisition.width - 4;
+  y = bounds.y + bounds.height / 2 - requisition.height / 2;
+
+  if (x >= monitor.x)
+    {
+      if (tooltip->keyboard_mode_enabled)
+        goto found;
+
+      if (x + requisition.width >= tooltip->last_x - MAX_DISTANCE)
+        {
+          if (tooltip->last_y + cursor_size + MAX_DISTANCE < y)
+            y = tooltip->last_y + cursor_size + MAX_DISTANCE;
+          else if (y + requisition.height < tooltip->last_y - MAX_DISTANCE)
+            y = tooltip->last_y - MAX_DISTANCE - requisition.height;
+
+          goto found;
+        }
+    }
+
+   /* Fallback */
   if (tooltip->keyboard_mode_enabled)
     {
-      gdk_window_get_origin (new_tooltip_widget->window, &x, &y);
-      if (GTK_WIDGET_NO_WINDOW (new_tooltip_widget))
-        {
-	  x += new_tooltip_widget->allocation.x;
-	  y += new_tooltip_widget->allocation.y;
-	}
-
-      /* For keyboard mode we position the tooltip below the widget,
-       * right of the center of the widget.
-       */
-      x += new_tooltip_widget->allocation.width / 2;
-      y += new_tooltip_widget->allocation.height + 4;
+      x = bounds.x + bounds.width / 2 - requisition.width / 2;
+      y = bounds.y + bounds.height + 4;
     }
   else
     {
-      guint cursor_size;
-
-      x = tooltip->last_x;
-      y = tooltip->last_y;
-
-      /* For mouse mode, we position the tooltip right of the cursor,
-       * a little below the cursor's center.
-       */
-      cursor_size = gdk_display_get_default_cursor_size (display);
-      x += cursor_size / 2;
-      y += cursor_size / 2;
+      /* At cursor */
+      x = tooltip->last_x + cursor_size * 3 / 4;
+      y = tooltip->last_y + cursor_size * 3 / 4;
     }
 
-  screen = gtk_widget_get_screen (new_tooltip_widget);
-
+found:
   /* Show it */
   if (tooltip->current_window)
     {
-      gint monitor_num;
-      GdkRectangle monitor;
-      GtkRequisition requisition;
-
-      gtk_widget_size_request (GTK_WIDGET (tooltip->current_window),
-                               &requisition);
-
-      monitor_num = gdk_screen_get_monitor_at_point (screen, x, y);
-      gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
-
       if (x + requisition.width > monitor.x + monitor.width)
         x -= x - (monitor.x + monitor.width) + requisition.width;
       else if (x < monitor.x)
@@ -923,7 +1032,9 @@ gtk_tooltip_position (GtkTooltip *tooltip,
 
       if (y + requisition.height > monitor.y + monitor.height)
         y -= y - (monitor.y + monitor.height) + requisition.height;
-  
+      else if (y < monitor.y)
+        y = monitor.y;
+
       if (!tooltip->keyboard_mode_enabled)
         {
           /* don't pop up under the pointer */
@@ -931,7 +1042,7 @@ gtk_tooltip_position (GtkTooltip *tooltip,
               y <= tooltip->last_y && tooltip->last_y < y + requisition.height)
             y = tooltip->last_y - requisition.height - 2;
         }
-  
+
       gtk_window_move (GTK_WINDOW (tooltip->current_window), x, y);
       gtk_widget_show (GTK_WIDGET (tooltip->current_window));
     }
@@ -960,14 +1071,18 @@ gtk_tooltip_show_tooltip (GdkDisplay *display)
     }
   else
     {
+      gint tx, ty;
+
       window = tooltip->last_window;
 
       if (!GDK_IS_WINDOW (window))
 	return;
 
-      gdk_window_get_origin (window, &x, &y);
-      x = tooltip->last_x - x;
-      y = tooltip->last_y - y;
+      gdk_window_get_pointer (window, &x, &y, NULL);
+
+      gdk_window_get_root_coords (window, x, y, &tx, &ty);
+      tooltip->last_x = tx;
+      tooltip->last_y = ty;
 
       pointer_widget = tooltip_widget = find_widget_under_pointer (window,
 								   &x, &y);
@@ -1290,9 +1405,6 @@ _gtk_tooltip_handle_event (GdkEvent *event)
   if (current_tooltip)
     {
       gtk_tooltip_set_last_window (current_tooltip, event->any.window);
-      gdk_event_get_root_coords (event,
-				&current_tooltip->last_x,
-				&current_tooltip->last_y);
     }
 
   if (current_tooltip && current_tooltip->keyboard_mode_enabled)
@@ -1398,9 +1510,6 @@ _gtk_tooltip_handle_event (GdkEvent *event)
 			      current_tooltip);
 
 	    gtk_tooltip_set_last_window (current_tooltip, event->any.window);
-	    gdk_event_get_root_coords (event,
-				       &current_tooltip->last_x,
-				       &current_tooltip->last_y);
 
 	    gtk_tooltip_start_delay (display);
 	  }
