@@ -69,8 +69,6 @@ GType gtk_attach_options_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_ATTACH_OPTIONS (gtk_attach_options_get_type ())
 GType gtk_button_box_style_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_BUTTON_BOX_STYLE (gtk_button_box_style_get_type ())
-GType gtk_curve_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CURVE_TYPE (gtk_curve_type_get_type ())
 GType gtk_delete_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_DELETE_TYPE (gtk_delete_type_get_type ())
 GType gtk_direction_type_get_type (void) G_GNUC_CONST;
@@ -81,14 +79,10 @@ GType gtk_icon_size_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_ICON_SIZE (gtk_icon_size_get_type ())
 GType gtk_sensitivity_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_SENSITIVITY_TYPE (gtk_sensitivity_type_get_type ())
-GType gtk_side_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_SIDE_TYPE (gtk_side_type_get_type ())
 GType gtk_text_direction_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_TEXT_DIRECTION (gtk_text_direction_get_type ())
 GType gtk_justification_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_JUSTIFICATION (gtk_justification_get_type ())
-GType gtk_match_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_MATCH_TYPE (gtk_match_type_get_type ())
 GType gtk_menu_direction_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_MENU_DIRECTION_TYPE (gtk_menu_direction_type_get_type ())
 GType gtk_message_type_get_type (void) G_GNUC_CONST;
@@ -113,14 +107,10 @@ GType gtk_policy_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_POLICY_TYPE (gtk_policy_type_get_type ())
 GType gtk_position_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_POSITION_TYPE (gtk_position_type_get_type ())
-GType gtk_preview_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_PREVIEW_TYPE (gtk_preview_type_get_type ())
 GType gtk_relief_style_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_RELIEF_STYLE (gtk_relief_style_get_type ())
 GType gtk_resize_mode_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_RESIZE_MODE (gtk_resize_mode_get_type ())
-GType gtk_signal_run_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_SIGNAL_RUN_TYPE (gtk_signal_run_type_get_type ())
 GType gtk_scroll_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_SCROLL_TYPE (gtk_scroll_type_get_type ())
 GType gtk_selection_mode_get_type (void) G_GNUC_CONST;
@@ -209,8 +199,6 @@ GType gtk_notebook_tab_get_type (void) G_GNUC_CONST;
 /* enumerations from "gtkobject.h" */
 GType gtk_object_flags_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_OBJECT_FLAGS (gtk_object_flags_get_type ())
-GType gtk_arg_flags_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_ARG_FLAGS (gtk_arg_flags_get_type ())
 
 /* enumerations from "gtkprintoperation.h" */
 GType gtk_print_status_get_type (void) G_GNUC_CONST;
@@ -280,6 +268,10 @@ GType gtk_toolbar_child_type_get_type (void) G_GNUC_CONST;
 GType gtk_toolbar_space_style_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_TOOLBAR_SPACE_STYLE (gtk_toolbar_space_style_get_type ())
 
+/* enumerations from "gtktoolpalette.h" */
+GType gtk_tool_palette_drag_targets_get_type (void) G_GNUC_CONST;
+#define GTK_TYPE_TOOL_PALETTE_DRAG_TARGETS (gtk_tool_palette_drag_targets_get_type ())
+
 /* enumerations from "gtktreemodel.h" */
 GType gtk_tree_model_flags_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_TREE_MODEL_FLAGS (gtk_tree_model_flags_get_type ())
@@ -301,28 +293,6 @@ GType gtk_widget_flags_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_WIDGET_FLAGS (gtk_widget_flags_get_type ())
 GType gtk_widget_help_type_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_WIDGET_HELP_TYPE (gtk_widget_help_type_get_type ())
-
-/* enumerations from "gtktree.h" */
-GType gtk_tree_view_mode_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_TREE_VIEW_MODE (gtk_tree_view_mode_get_type ())
-
-/* enumerations from "gtkclist.h" */
-GType gtk_cell_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CELL_TYPE (gtk_cell_type_get_type ())
-GType gtk_clist_drag_pos_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CLIST_DRAG_POS (gtk_clist_drag_pos_get_type ())
-GType gtk_button_action_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_BUTTON_ACTION (gtk_button_action_get_type ())
-
-/* enumerations from "gtkctree.h" */
-GType gtk_ctree_pos_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CTREE_POS (gtk_ctree_pos_get_type ())
-GType gtk_ctree_line_style_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CTREE_LINE_STYLE (gtk_ctree_line_style_get_type ())
-GType gtk_ctree_expander_style_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CTREE_EXPANDER_STYLE (gtk_ctree_expander_style_get_type ())
-GType gtk_ctree_expansion_type_get_type (void) G_GNUC_CONST;
-#define GTK_TYPE_CTREE_EXPANSION_TYPE (gtk_ctree_expansion_type_get_type ())
 G_END_DECLS
 
 #endif /* __GTK_TYPE_BUILTINS_H__ */
